==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/TagEventConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TagEventConditionBuilder extends io.fabric8.openshift.api.model.TagEventConditionFluentImpl<io.fabric8.openshift.api.model.TagEventConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.TagEventCondition,io.fabric8.openshift.api.model.TagEventConditionBuilder>{
  public TagEventConditionBuilder() {
    this(false);
  }
  public TagEventConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new TagEventCondition(), validationEnabled);
  }
  public TagEventConditionBuilder(io.fabric8.openshift.api.model.TagEventConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public TagEventConditionBuilder(io.fabric8.openshift.api.model.TagEventConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new TagEventCondition(), validationEnabled);
  }
  public TagEventConditionBuilder(io.fabric8.openshift.api.model.TagEventConditionFluent<?> fluent,io.fabric8.openshift.api.model.TagEventCondition instance) {
    this(fluent, instance, false);
  }
  public TagEventConditionBuilder(io.fabric8.openshift.api.model.TagEventConditionFluent<?> fluent,io.fabric8.openshift.api.model.TagEventCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGeneration(instance.getGeneration()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TagEventConditionBuilder(io.fabric8.openshift.api.model.TagEventCondition instance) {
    this(instance,false);
  }
  public TagEventConditionBuilder(io.fabric8.openshift.api.model.TagEventCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGeneration(instance.getGeneration()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.TagEventConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.TagEventCondition build() {
    TagEventCondition buildable = new TagEventCondition(fluent.getGeneration(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TagEventConditionBuilder that = (TagEventConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-6.0.0-sources.jar: io/fabric8/openshift/api/model/TagEventConditionBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TagEventConditionBuilder extends TagEventConditionFluentImpl<TagEventConditionBuilder> implements VisitableBuilder<TagEventCondition,TagEventConditionBuilder>{
  public TagEventConditionBuilder() {
    this(false);
  }
  public TagEventConditionBuilder(Boolean validationEnabled) {
    this(new TagEventCondition(), validationEnabled);
  }
  public TagEventConditionBuilder(TagEventConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public TagEventConditionBuilder(TagEventConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new TagEventCondition(), validationEnabled);
  }
  public TagEventConditionBuilder(TagEventConditionFluent<?> fluent,TagEventCondition instance) {
    this(fluent, instance, false);
  }
  public TagEventConditionBuilder(TagEventConditionFluent<?> fluent,TagEventCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGeneration(instance.getGeneration()); 
    fluent.withLastTransitionTime(instance.getLastTransitionTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TagEventConditionBuilder(TagEventCondition instance) {
    this(instance,false);
  }
  public TagEventConditionBuilder(TagEventCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withGeneration(instance.getGeneration()); 
    this.withLastTransitionTime(instance.getLastTransitionTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  TagEventConditionFluent<?> fluent;
  Boolean validationEnabled;
  public TagEventCondition build() {
    TagEventCondition buildable = new TagEventCondition(fluent.getGeneration(),fluent.getLastTransitionTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
